@@ -21,13 +21,13 @@
 
 #include "proto.h"
 
+#ifdef ENABLE_BROWSER
+
 #include <errno.h>
 #include <stdint.h>
 #include <string.h>
 #include <unistd.h>
 
-#ifdef ENABLE_BROWSER
-
 static char **filelist = NULL;
 		/* The list of files to display in the file browser. */
 static size_t filelist_len = 0;
@@ -77,8 +77,6 @@ char *do_browser(char *path)
 		present_name = mallocstrcpy(present_name, filelist[selected]);
 	}
 
-	assert(path != NULL && path[strlen(path) - 1] == '/');
-
 	if (dir != NULL) {
 		/* Get the file list, and set longest and width in the process. */
 		read_the_list(path, dir);
@@ -155,9 +153,9 @@ char *do_browser(char *path)
 			/* Simulate a window resize to force a directory reread. */
 			kbinput = KEY_WINCH;
 #endif
-		} else if (func == do_help_void) {
+		} else if (func == do_help) {
 #ifdef ENABLE_HELP
-			do_help_void();
+			do_help();
 #ifndef NANO_TINY
 			/* The window dimensions might have changed, so act as if. */
 			kbinput = KEY_WINCH;
@@ -223,11 +221,9 @@ char *do_browser(char *path)
 			selected = filelist_len - 1;
 		} else if (func == goto_dir_void) {
 			/* Ask for the directory to go to. */
-			int i = do_prompt(TRUE, FALSE, MGOTODIR, NULL, NULL,
-						/* TRANSLATORS: This is a prompt. */
-						browser_refresh, _("Go To Directory"));
-
-			if (i < 0) {
+			if (do_prompt(TRUE, FALSE, MGOTODIR, "", NULL,
+							/* TRANSLATORS: This is a prompt. */
+							browser_refresh, _("Go To Directory")) < 0) {
 				statusbar(_("Cancelled"));
 				continue;
 			}
@@ -289,7 +285,7 @@ char *do_browser(char *path)
 
 			/* If it isn't a directory, a file was selected -- we're done. */
 			if (!S_ISDIR(st.st_mode)) {
-				retval = mallocstrcpy(NULL, filelist[selected]);
+				retval = copy_of(filelist[selected]);
 				break;
 			}
 
@@ -305,13 +301,12 @@ char *do_browser(char *path)
 		} else if (func == (functionptrtype)implant) {
 			implant(first_sc_for(MBROWSER, func)->expansion);
 #endif
-		} else if (func == do_exit) {
-			/* Exit from the file browser. */
-			break;
 #ifndef NANO_TINY
 		} else if (kbinput == KEY_WINCH) {
-			;
+			;  /* Nothing to do. */
 #endif
+		} else if (func == do_exit) {
+			break;
 		} else
 			unbound_key(kbinput);
 
@@ -319,7 +314,7 @@ char *do_browser(char *path)
 		/* If the window resized, refresh the file list. */
 		if (kbinput == KEY_WINCH) {
 			/* Remember the selected file, to be able to reselect it. */
-			present_name = mallocstrcpy(NULL, filelist[selected]);
+			present_name = copy_of(filelist[selected]);
 			/* Reread the contents of the current directory. */
 			goto read_directory_contents;
 		}
@@ -394,8 +389,6 @@ void read_the_list(const char *path, DIR *dir)
 	const struct dirent *nextdir;
 	size_t i = 0, path_len = strlen(path);
 
-	assert(path != NULL && path[strlen(path) - 1] == '/' && dir != NULL);
-
 	longest = 0;
 
 	/* Find the length of the longest filename in the current folder. */
@@ -445,8 +438,6 @@ void read_the_list(const char *path, DIR *dir)
 	 * filelist, so record it. */
 	filelist_len = i;
 
-	assert(filelist != NULL);
-
 	/* Sort the list of names. */
 	qsort(filelist, filelist_len, sizeof(char *), diralphasort);
 
@@ -462,26 +453,10 @@ functionptrtype parse_browser_input(int *kbinput)
 {
 	if (!meta_key) {
 		switch (*kbinput) {
-			case BS_CODE:
 			case '-':
 				return do_page_up;
 			case ' ':
 				return do_page_down;
-			case '?':
-				return do_help_void;
-			case 'E':
-			case 'e':
-			case 'Q':
-			case 'q':
-			case 'X':
-			case 'x':
-				return do_exit;
-			case 'G':
-			case 'g':
-				return goto_dir_void;
-			case 'S':
-			case 's':
-				return do_enter;
 			case 'W':
 			case 'w':
 			case '/':
@@ -490,6 +465,21 @@ functionptrtype parse_browser_input(int *kbinput)
 				return do_findprevious;
 			case 'n':
 				return do_findnext;
+			case 'G':
+			case 'g':
+				return goto_dir_void;
+			case '?':
+				return do_help;
+			case 'S':
+			case 's':
+				return do_enter;
+			case 'E':
+			case 'e':
+			case 'Q':
+			case 'q':
+			case 'X':
+			case 'x':
+				return do_exit;
 		}
 	}
 	return func_from_key(kbinput);
@@ -533,16 +523,15 @@ void browser_refresh(void)
 				/* The filename (or a fragment of it) in displayable format.
 				 * When a fragment, account for dots plus one space padding. */
 
-		/* If this is the selected item, start its highlighting, and
+		/* If this is the selected item, draw its highlighted bar upfront, and
 		 * remember its location to be able to place the cursor on it. */
 		if (i == selected) {
 			wattron(edit, interface_color_pair[SELECTED_TEXT]);
+			mvwprintw(edit, row, col, "%*s", longest, " ");
 			the_row = row;
 			the_column = col;
 		}
 
-		blank_row(edit, row, col, longest);
-
 		/* If the name is too long, we display something like "...ename". */
 		if (dots)
 			mvwaddstr(edit, row, col, "...");
@@ -557,17 +546,17 @@ void browser_refresh(void)
 		 * "(dir)" for directories, and the file size for normal files. */
 		if (lstat(filelist[i], &st) == -1 || S_ISLNK(st.st_mode)) {
 			if (stat(filelist[i], &st) == -1 || !S_ISDIR(st.st_mode))
-				info = mallocstrcpy(NULL, "--");
+				info = copy_of("--");
 			else
 				/* TRANSLATORS: Try to keep this at most 7 characters. */
-				info = mallocstrcpy(NULL, _("(dir)"));
+				info = copy_of(_("(dir)"));
 		} else if (S_ISDIR(st.st_mode)) {
 			if (strcmp(thename, "..") == 0) {
 				/* TRANSLATORS: Try to keep this at most 12 characters. */
-				info = mallocstrcpy(NULL, _("(parent dir)"));
+				info = copy_of(_("(parent dir)"));
 				infomaxlen = 12;
 			} else
-				info = mallocstrcpy(NULL, _("(dir)"));
+				info = copy_of(_("(dir)"));
 		} else {
 			off_t result = st.st_size;
 			char modifier;
@@ -675,11 +664,12 @@ int filesearch_init(bool forwards)
 				(breadth(last_search) > COLS / 3) ? "..." : "");
 		free(disp);
 	} else
-		thedefault = mallocstrcpy(NULL, "");
+		thedefault = copy_of("");
 
 	/* Now ask what to search for. */
-	response = do_prompt(FALSE, FALSE, MWHEREISFILE, NULL, &search_history,
+	response = do_prompt(FALSE, FALSE, MWHEREISFILE, "", &search_history,
 						browser_refresh, "%s%s%s", _("Search"),
+						/* TRANSLATORS: A modifier of the Search prompt. */
 						!forwards ? _(" [Backwards]") : "", thedefault);
 	free(thedefault);
 
@@ -802,7 +792,7 @@ void to_last_file(void)
  * The returned string is dynamically allocated, and should be freed. */
 char *strip_last_component(const char *path)
 {
-	char *copy = mallocstrcpy(NULL, path);
+	char *copy = copy_of(path);
 	char *last_slash = strrchr(copy, '/');
 
 	if (last_slash != NULL)
