@@ -21,11 +21,11 @@
 
 #include "proto.h"
 
+#ifdef ENABLE_HISTORIES
+
 #include <errno.h>
 #include <string.h>
 
-#ifdef ENABLE_HISTORIES
-
 #ifndef SEARCH_HISTORY
 #define SEARCH_HISTORY "search_history"
 #endif
@@ -48,17 +48,17 @@ static poshiststruct *position_history = NULL;
 void history_init(void)
 {
 	search_history = make_new_node(NULL);
-	search_history->data = mallocstrcpy(NULL, "");
+	search_history->data = copy_of("");
 	searchtop = search_history;
 	searchbot = search_history;
 
 	replace_history = make_new_node(NULL);
-	replace_history->data = mallocstrcpy(NULL, "");
+	replace_history->data = copy_of("");
 	replacetop = replace_history;
 	replacebot = replace_history;
 
 	execute_history = make_new_node(NULL);
-	execute_history->data = mallocstrcpy(NULL, "");
+	execute_history->data = copy_of("");
 	executetop = execute_history;
 	executebot = execute_history;
 }
@@ -136,7 +136,7 @@ void update_history(linestruct **item, const char *text)
 	(*hbot)->data = mallocstrcpy((*hbot)->data, text);
 	splice_node(*hbot, make_new_node(*hbot));
 	*hbot = (*hbot)->next;
-	(*hbot)->data = mallocstrcpy(NULL, "");
+	(*hbot)->data = copy_of("");
 
 	/* Indicate that the history needs to be saved on exit. */
 	history_changed = TRUE;
@@ -229,19 +229,6 @@ char *get_history_completion(linestruct **h, char *s, size_t len)
 }
 #endif /* ENABLE_TABCOMP */
 
-void history_error(const char *msg, ...)
-{
-	va_list ap;
-
-	va_start(ap, msg);
-	vfprintf(stderr, _(msg), ap);
-	va_end(ap);
-
-	fprintf(stderr, _("\nPress Enter to continue\n"));
-	while (getchar() != '\n')
-		;
-}
-
 /* Check whether we have or could make a directory for history files. */
 bool have_statedir(void)
 {
@@ -280,14 +267,14 @@ bool have_statedir(void)
 			free(statepath);
 		}
 		if (mkdir(statedir, S_IRWXU) == -1) {
-			history_error(N_("Unable to create directory %s: %s\n"
+			jot_error(N_("Unable to create directory %s: %s\n"
 								"It is required for saving/loading "
 								"search history or cursor positions.\n"),
 								statedir, strerror(errno));
 			return FALSE;
 		}
 	} else if (!S_ISDIR(dirstat.st_mode)) {
-		history_error(N_("Path %s is not a directory and needs to be.\n"
+		jot_error(N_("Path %s is not a directory and needs to be.\n"
 								"Nano will be unable to load or save "
 								"search history or cursor positions.\n"),
 								statedir);
@@ -308,7 +295,7 @@ void load_history(void)
 		if (errno != ENOENT) {
 			/* When reading failed, don't save history when we quit. */
 			UNSET(HISTORYLOG);
-			history_error(N_("Error reading %s: %s"), histname,
+			jot_error(N_("Error reading %s: %s"), histname,
 						strerror(errno));
 		}
 	} else {
@@ -404,7 +391,7 @@ void load_poshistory(void)
 		if (errno != ENOENT) {
 			/* When reading failed, don't save history when we quit. */
 			UNSET(POSITIONLOG);
-			history_error(N_("Error reading %s: %s"), poshistname, strerror(errno));
+			jot_error(N_("Error reading %s: %s"), poshistname, strerror(errno));
 		}
 	} else {
 		char *line = NULL, *lineptr, *xptr;
@@ -414,7 +401,7 @@ void load_poshistory(void)
 
 		/* Read and parse each line, and store the extracted data. */
 		while ((read = getline(&line, &buf_len, hisfile)) > 5) {
-			/* Decode nulls as embedded newlines. */
+			/* Decode NULs as embedded newlines. */
 			unsunder(line, read);
 
 			/* Find where the x index and line number are in the line. */
@@ -431,7 +418,7 @@ void load_poshistory(void)
 
 			/* Create a new position record. */
 			newrecord = (poshiststruct *)nmalloc(sizeof(poshiststruct));
-			newrecord->filename = mallocstrcpy(NULL, line);
+			newrecord->filename = copy_of(line);
 			newrecord->lineno = atoi(lineptr);
 			newrecord->xno = atoi(xptr);
 			newrecord->next = NULL;
@@ -484,7 +471,7 @@ void save_poshistory(void)
 						posptr->filename, posptr->lineno, posptr->xno);
 			length = strlen(path_and_place);
 
-			/* Encode newlines in filenames as nulls. */
+			/* Encode newlines in filenames as NULs. */
 			sunder(path_and_place);
 			/* Restore the terminating newline. */
 			path_and_place[length - 1] = '\n';
@@ -528,7 +515,7 @@ void update_poshistory(char *filename, ssize_t lineno, ssize_t xpos)
 	poshiststruct *posptr, *theone, *posprev = NULL;
 	char *fullpath = get_full_path(filename);
 
-	if (fullpath == NULL || fullpath[strlen(fullpath) - 1] == '/') {
+	if (fullpath == NULL || *filename == '\0') {
 		free(fullpath);
 		return;
 	}
@@ -563,7 +550,7 @@ void update_poshistory(char *filename, ssize_t lineno, ssize_t xpos)
 	 * not at the end, move the matching one to the end. */
 	if (theone == NULL) {
 		theone = (poshiststruct *)nmalloc(sizeof(poshiststruct));
-		theone->filename = mallocstrcpy(NULL, fullpath);
+		theone->filename = copy_of(fullpath);
 		if (position_history == NULL)
 			position_history = theone;
 		else
